@@ -18,32 +18,157 @@ class ChatManager:
         self.client = client
         self._page = client._page
         self.wa_elements = client.wa_elements
-
-    async def _check_unread_chats(self):
-        """Verifica y devuelve los chats no leídos"""
+    async def _check_unread_chats(self, debug=False):
         unread_chats = []
+        page = self._page
+        
         try:
-            unread_button = await self._page.query_selector(loc.UNREAD_CHATS_BUTTON)
-            if unread_button:
-                await unread_button.click()
-                await asyncio.sleep(self.client.unread_messages_sleep)
-
-                chat_list = await self._page.query_selector_all(loc.UNREAD_CHAT_DIV)
-                if chat_list and len(chat_list) > 0:
-                    chats = await chat_list[0].query_selector_all(loc.SEARCH_ITEM)
-                    for chat in chats:
-                        chat_result = await self._parse_search_result(chat, "CHATS")
+            # DEBUG: Inspeccionar estructura general si está activado
+            if debug:
+                total_items = await page.locator("[role='listitem']").count()
+                print(f"DEBUG: Total elementos listitem en la página: {total_items}")
+                
+                # Analizar primeros 3 chats para entender la estructura
+                for i in range(min(3, total_items)):
+                    item = page.locator("[role='listitem']").nth(i)
+                    text_content = await item.text_content()
+                    
+                    print(f"\n--- ESTRUCTURA CHAT {i+1} ---")
+                    print(f"Texto: {text_content[:80]}...")
+                    
+                    # Verificar badges existentes
+                    badges_x140p0ai = await item.locator(".x140p0ai").count()
+                    badges_ahlk = await item.locator("._ahlk").count() 
+                    badges_xn58pb5 = await item.locator(".xn58pb5").count()
+                    
+                    print(f"Badges .x140p0ai: {badges_x140p0ai}")
+                    print(f"Badges ._ahlk: {badges_ahlk}")
+                    print(f"Badges .xn58pb5: {badges_xn58pb5}")
+                    
+                    # Verificar aria-labels relevantes con timeout más corto
+                    try:
+                        aria_elements = await item.locator("[aria-label*='unread' i], [aria-label*='message' i]").all(timeout=5000)
+                        for elem in aria_elements:
+                            label_text = await elem.get_attribute("aria-label", timeout=2000)
+                            if label_text:
+                                print(f"Aria-label relevante: {label_text}")
+                    except Exception as e:
+                        if debug:
+                            print(f"DEBUG: Timeout en aria-labels para chat {i+1}: {e}")
+            
+            # CAMBIO CRÍTICO: Buscar directamente en toda la página, no en una "lista"
+            # porque el problema es que no encuentra la lista contenedora correcta
+            items_unread = page.locator(
+                # Estrategia DIRECTA: buscar listitem con badges específicos
+                "[role='listitem']:has(.x140p0ai), "  # Badge principal
+                "[role='listitem']:has(._ahlk), "     # Contenedor del badge  
+                "[role='listitem']:has(.xn58pb5), "   # Badge específico
+                
+                # Estrategia de aria-labels
+                "[role='listitem']:has([aria-label*='unread' i]), "
+                "[role='listitem']:has([aria-label*='message' i]:not([aria-label*='0 message'])), "
+                "[role='listitem']:has([aria-label*='no leído' i]), "
+                "[role='listitem']:has([aria-label*='sin leer' i])"
+            )
+            
+            n = await items_unread.count()
+            if debug:
+                print(f"DEBUG: Selector directo encontró {n} chats no leídos")
+            
+            if n == 0:
+                if debug:
+                    print("DEBUG: Selector directo no encontró nada. Probando selector por posición...")
+                
+                # Si no funciona el selector, buscar por posición específica
+                # Sabemos que chat 1 tiene badges según el debug
+                first_chat = page.locator("[role='listitem']").first
+                has_badge_first = await first_chat.locator(".x140p0ai, ._ahlk, .xn58pb5").count()
+                
+                if debug:
+                    print(f"DEBUG: Primer chat tiene {has_badge_first} badges")
+                
+                if has_badge_first > 0:
+                    if debug:
+                        print("DEBUG: Agregando primer chat manualmente...")
+                    items_unread = page.locator("[role='listitem']").first
+                    n = 1
+                else:
+                    # Lista virtualizada: scroll más suave y específico
+                    if debug:
+                        print("DEBUG: Intentando scroll...")
+                    
+                    await page.mouse.wheel(0, 800)
+                    await asyncio.sleep(0.3)
+                    await page.mouse.wheel(0, -800)
+                    await asyncio.sleep(0.3)
+                    
+                    # Reintentar detección
+                    items_unread = page.locator("[role='listitem']:has(.x140p0ai), [role='listitem']:has(._ahlk)")
+                    n = await items_unread.count()
+                    if debug:
+                        print(f"DEBUG: Después del scroll se encontraron {n} chats no leídos")
+            
+            # Procesar los chats encontrados
+            for i in range(n):
+                try:
+                    # Si n=1 y usamos first, no usar nth()
+                    if n == 1 and isinstance(items_unread.locator, type(page.locator("[role='listitem']").first.locator)):
+                        item = items_unread
+                    else:
+                        item = items_unread.nth(i)
+                    
+                    # DEBUG: Información detallada del item
+                    if debug:
+                        try:
+                            item_text = await item.text_content(timeout=5000)
+                            print(f"\n--- PROCESANDO CHAT {i+1} ---")
+                            print(f"Texto del chat: {item_text[:60]}...")
+                        except Exception as text_error:
+                            print(f"\n--- PROCESANDO CHAT {i+1} ---")
+                            print(f"Error obteniendo texto: {text_error}")
+                    
+                    # Verificación adicional: asegurar que realmente tiene badge de no leído
+                    has_badge = await item.locator(
+                        ".x140p0ai, "  # Badge principal
+                        "[aria-label*='unread' i], "
+                        "[aria-label*='message' i], "
+                        "._ahlk, "
+                        ".xn58pb5"
+                    ).count()
+                    
+                    if debug:
+                        print(f"Badges confirmados en este chat: {has_badge}")
+                    
+                    if has_badge > 0:
+                        # Si tu parser espera ElementHandle:
+                        handle = await item.element_handle()
+                        chat_result = await self._parse_search_result(handle, "CHATS")
+                        
                         if chat_result:
                             unread_chats.append(chat_result)
-
-            # Volver a la vista de todos los chats
-            all_button = await self._page.query_selector(loc.ALL_CHATS_BUTTON)
-            if all_button:
-                await all_button.click()
-
+                            if debug:
+                                print(f"✓ Chat no leído agregado: {chat_result.get('name', 'Sin nombre')}")
+                        elif debug:
+                            print("✗ Parser no pudo procesar este chat")
+                    elif debug:
+                        print("✗ Chat descartado: no tiene badge de no leído")
+                            
+                except Exception as item_error:
+                    if debug:
+                        print(f"DEBUG: Error procesando item {i}: {item_error}")
+                    continue
+                    
         except Exception as e:
-            await self.client.emit("on_warning", f"Error al verificar chats no leídos: {e}")
-
+            await self.client.emit("on_warning", f"Error detectando no leídos (adaptado): {e}")
+            if debug:
+                print(f"DEBUG: Error general: {e}")
+        
+        if debug:
+            print(f"\nDEBUG: ===== RESUMEN =====")
+            print(f"Total chats no leídos encontrados: {len(unread_chats)}")
+            for i, chat in enumerate(unread_chats):
+                print(f"  {i+1}. {chat.get('name', 'Sin nombre')}")
+        
         return unread_chats
 
     async def _parse_search_result(
@@ -176,7 +301,7 @@ class ChatManager:
         """
         resultados: List[Union[Message, FileMessage]] = []
         msg_elements = await self._page.query_selector_all(
-            'div[class*="message-in"], div[class*="message-out"]'
+            'div[class*="message-in"]'
         )
 
         for elem in msg_elements:
