@@ -71,19 +71,23 @@ class WhatsAppElements:
                         selector, timeout=1000, state="visible"
                     )
                     if element:
+                        print(f"🔎 click_search_button: clic en botón de búsqueda con selector: {selector}")
                         await element.click()
                         if await self.verify_search_active():
+                            print("✅ click_search_button: búsqueda activada vía botón")
                             return True
                 except Exception:
                     continue
 
             # Si no funcionó el clic directo, intentar con atajos de teclado
-            shortcuts = ["Control+/", "Control+f", "/", "Slash"]
+            shortcuts = ["Control+Alt+/", "Control+Alt+Slash", "Control+/", "Control+f", "/", "Slash"]
             for shortcut in shortcuts:
                 try:
                     await self.page.keyboard.press("Escape")  # Limpiar estado actual
+                    print(f"⌨️  click_search_button: probando atajo {shortcut}")
                     await self.page.keyboard.press(shortcut)
                     if await self.verify_search_active():
+                        print(f"✅ click_search_button: búsqueda activada con atajo {shortcut}")
                         return True
                 except Exception:
                     continue
@@ -198,41 +202,82 @@ class WhatsAppElements:
         """
         Abre un chat por su nombre visible. Si no está en el DOM, lo busca y lo abre.
         """
-        es_numero = bool(re.fullmatch(r"\+?\d+", chat_name))
+        # es_numero = bool(re.fullmatch(r"\+?\d+", chat_name))
 
-        if es_numero or force_open:
-            numero = chat_name.lstrip("+")
-            url = f"https://web.whatsapp.com/send?phone={numero}"
-            await self.page.goto(url)
+        # if es_numero or force_open:
+        #     numero = chat_name.lstrip("+")
+        #     url = f"https://web.whatsapp.com/send?phone={numero}"
+        #     await self.page.goto(url)
+        #     try:
+        #         await self.page.wait_for_selector(loc.CHAT_INPUT_BOX, timeout=timeout)
+        #         return True
+        #     except Exception:
+        #         # Si falla la navegación directa, continuamos con estrategias de búsqueda
+        #         pass
 
-        span_xpath = f"//span[contains(@title, {repr(chat_name)})]"
+        # Estrategia 1: buscar el chat directamente en la lista (exacto y luego parcial)
+        exact_xpath = f"//span[@title={repr(chat_name)}]"
+        contains_xpath = f"//span[contains(@title, {repr(chat_name)})]"
 
         try:
-            chat_element = await self.page.query_selector(f"xpath={span_xpath}")
+            chat_element = await self.page.query_selector(f"xpath={exact_xpath}")
+            if not chat_element:
+                chat_element = await self.page.query_selector(f"xpath={contains_xpath}")
             if chat_element:
+                try:
+                    await chat_element.scroll_into_view_if_needed()
+                except Exception:
+                    pass
                 await chat_element.click()
-                print(f"✅ Chat '{chat_name}' abierto directamente.")
+                if await self.page.query_selector(f"xpath={exact_xpath}"):
+                    print(f"✅ open: abierto por coincidencia EXACTA de título → {chat_name}")
+                else:
+                    print(f"✅ open: abierto por coincidencia PARCIAL de título → {chat_name}")
             else:
                 print(f"🔍 Chat '{chat_name}' no visible, usando buscador...")
-                for btn in loc.SEARCH_BUTTON:
-                    btns = await self.page.query_selector_all(f"xpath={btn}")
-                    if btns:
-                        await btns[0].click()
-                        break
-                else:
-                    raise Exception("❌ Botón de búsqueda no encontrado")
+                # Usar método robusto que incluye atajos de teclado
+                if not await self.click_search_button():
+                    raise Exception("❌ No se pudo activar el buscador")
 
                 for input_xpath in loc.SEARCH_TEXT_BOX:
                     inputs = await self.page.query_selector_all(f"xpath={input_xpath}")
                     if inputs:
                         await inputs[0].fill(chat_name)
+                        print(f"⌨️  open: texto de búsqueda escrito → '{chat_name}' en {input_xpath}")
                         break
                 else:
                     raise Exception("❌ Input de búsqueda no encontrado")
 
+                # Esperar y seleccionar el mejor resultado (exacto primero)
                 await self.page.wait_for_selector(loc.SEARCH_ITEM, timeout=timeout)
-                await self.page.keyboard.press("ArrowDown")
-                await self.page.keyboard.press("Enter")
+                items = await self.page.locator(loc.SEARCH_ITEM).all()
+
+                best_item = None
+                best_partial = None
+                for item in items:
+                    try:
+                        text = (await item.inner_text()) or ""
+                        if text.strip() == chat_name:
+                            best_item = item
+                            break
+                        if chat_name.lower() in text.lower():
+                            best_partial = best_partial or item
+                    except Exception:
+                        continue
+
+                target = best_item or best_partial
+                if target:
+                    try:
+                        await target.scroll_into_view_if_needed()
+                    except Exception:
+                        pass
+                    await target.click()
+                    print("✅ open: selección desde buscador → ", "EXACTA" if best_item else "PARCIAL")
+                else:
+                    # Fallback al comportamiento anterior
+                    await self.page.keyboard.press("ArrowDown")
+                    await self.page.keyboard.press("Enter")
+                    print("↘️  open: fallback ArrowDown + Enter")
                 print(f"✅ Chat '{chat_name}' abierto desde buscador.")
 
             await self.page.wait_for_selector(loc.CHAT_INPUT_BOX, timeout=timeout)
@@ -356,45 +401,92 @@ class WhatsAppElements:
             if not await self.open(group_name, timeout=5000):
                 print(f"❌ No se pudo abrir el grupo '{group_name}'")
                 return False
-            
-            # 2. Hacer clic en la cabecera para abrir la info del grupo
+
+            # 1. Abrir info de grupo
+            print(" 1. Esperando GROUP_INFO_BUTTON...")
             header = await self.page.wait_for_selector(loc.GROUP_INFO_BUTTON, timeout=5000)
             await header.click()
 
-            # 3. Buscar al miembro, activar menú contextual y hacer clic
-            xpath_member_row = f'//span[@title="{member_name}"]/ancestor::div[@role="button"]'
-            member_row = await self.page.query_selector(f"xpath={xpath_member_row}")
+            # 2. Contenedor de info del grupo
+            print(" 2. Esperando contenedor 'Group info'...")
+            group_info = await self.page.wait_for_selector('div[aria-label="Group info"]', timeout=5000)
+            if not group_info:
+                print("❌ No se encontró el contenedor 'Group info'")
+                return False
 
-            if member_row:
-                await member_row.scroll_into_view_if_needed()
-                await member_row.hover()
+            # 3. Buscar el <span> del miembro por coincidencia parcial
+            print(" 3. Buscando miembro por coincidencia parcial...")
+            span_member = await group_info.evaluate_handle(
+                f"""
+                (container) => {{
+                    const spans = Array.from(container.querySelectorAll('span[title]'));
+                    return spans.find(s => s.textContent.trim().toLowerCase().includes("{member_name.lower()}")) || null;
+                }}
+                """
+            )
 
-                # Dale tiempo a que aparezca
-                try:
-                    context_menu_btn = await member_row.wait_for_selector(
-                        'button[aria-label="Open the chat context menu"]',
-                        timeout=3000
-                    )
-                    await context_menu_btn.click()
-                    print("✅ Menú contextual clickeado correctamente.")
-                except Exception as e:
-                    print(f"❌ No se pudo hacer clic en el botón del menú: {e}")
-                
-                remove_button = await self.page.wait_for_selector(
-                    loc.REMOVE_MEMBER_BUTTON, timeout=5000
+            # ⚠️ Verificar si se encontró o no
+            if not await span_member.evaluate("el => !!el"):
+                print(f"❌ No se encontró el miembro '{member_name}'")
+                return False
+
+            # 4. Subir al contenedor general del miembro (div[role="button"])
+            member_row = await span_member.evaluate_handle("el => el.closest('div[role=\"button\"]')")
+            if not await member_row.evaluate("el => !!el"):
+                print("⚠️ No se encontró el contenedor del miembro")
+                return False
+
+            # 5. Buscar el contenedor del status
+            status_container = await member_row.evaluate_handle(
+                """(row) => {
+                    const divs = Array.from(row.querySelectorAll('div'));
+                    return divs.find(div => {
+                        const span = div.querySelector('span');
+                        return span && span.getAttribute('title');
+                    }) || null;
+                }"""
+            )
+            if not await status_container.evaluate("el => !!el"):
+                print("⚠️ No se encontró el contenedor del estado del miembro")
+                return False
+
+            # 6. Hover sobre el estado
+            print(" 4. Hover sobre el estado...")
+            await status_container.scroll_into_view_if_needed()
+            await status_container.hover()
+            print(f"✅ Hover sobre el estado de '{member_name}'")
+
+            # 7. Esperar botón de menú
+            print(" 5. Esperando botón ⋮ ...")
+            try:
+                menu_btn = await self.page.wait_for_selector(
+                    'button[aria-label="Open the chat context menu"]',
+                    timeout=3000
                 )
-                await remove_button.click()
-                await asyncio.sleep(0.5)
-                confirm_button = await self.page.wait_for_selector('//div[text()="Remove"]', timeout=3000)
-                await confirm_button.click()
-                
-                print(f"✅ Miembro '{member_name}' eliminado de '{group_name}'.")
-            else:
-                print(f"🔍 Miembro '{member_name}' no encontrado en '{group_name}'")
-            return False
+                await menu_btn.click()
+                print("✅ Menú contextual clickeado correctamente.")
+            except Exception as e:
+                print(f"❌ No se pudo hacer clic en el botón del menú: {e}")
+                return False
+
+            # 8. Clic en "Remove"
+            remove_button = await self.page.wait_for_selector(loc.REMOVE_MEMBER_BUTTON, timeout=5000)
+            await remove_button.click()
+            await asyncio.sleep(0.5)
+
+            # 9. Confirmar
+            confirm_button = await self.page.wait_for_selector('//div[text()="Remove"]', timeout=3000)
+            await confirm_button.click()
+            await asyncio.sleep(0.5)
+
+            print(f"✅ Miembro '{member_name}' eliminado de '{group_name}'.")
+            return True
 
         except PlaywrightTimeoutError:
-            print(f"Timeout al intentar eliminar miembro de '{group_name}'")
+            print(f"⏱️ Timeout al intentar eliminar miembro de '{group_name}'")
+            await self.page.keyboard.press("Escape")
+            return False
+        except Exception as e:
+            print(f"❌ Error eliminando miembro '{member_name}' de '{group_name}': {e}")
             await self.page.keyboard.press("Escape")
             return False
-        
\ No newline at end of file
